package com.scansolutions.mrzsampleapp;

import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v7.app.AlertDialog;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.widget.ImageView;

import com.scansolutions.mrzscannerlib.MRZLicenceResultListener;
import com.scansolutions.mrzscannerlib.MRZResultModel;
import com.scansolutions.mrzscannerlib.MRZScanner;
import com.scansolutions.mrzscannerlib.MRZScannerListener;
import com.scansolutions.mrzscannerlib.ScannerType;


public class ScannerActivity extends AppCompatActivity implements MRZScannerListener {

    private static final String TAG = "ScannerActivity";
    MRZScanner mrzScanner;
    private static final String TYPE_EXTRA = "TYPE_EXTRA";
    public static void startScannerActivity(Context context, ScannerType type) {
        Intent intent = new Intent(context, ScannerActivity.class);
        intent.putExtra(TYPE_EXTRA, type);
        context.startActivity(intent);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_scanner);

        ScannerType type = (ScannerType) getIntent().getSerializableExtra(TYPE_EXTRA);

        mrzScanner = (MRZScanner) getSupportFragmentManager().findFragmentById(R.id.scannerFragment);
        mrzScanner.setScannerType(type);    // Options: [SCANNER_TYPE_MRZ, SCANNER_TYPE_DOC_IMAGE_ID, SCANNER_TYPE_DOC_IMAGE_PASSPORT]
        MRZScanner.setIDActive(true);                               // Enable/disable the ID document type
        MRZScanner.setPassportActive(true);                         // Enable/disable the Passport document type
        MRZScanner.setVisaActive(true);                             // Enable/disable the Visa document type
        MRZScanner.setMaxThreads(2);                                // Set the max CPU threads that the scanner can use

        MRZScanner.registerWithLicenseKey(this, "licence_key", new MRZLicenceResultListener() {
            @Override
            public void onRegisterWithLicenceResult(int result, @Nullable String errorMessage) {
                if (errorMessage != null) {
                    Log.i(TAG, "Result code: " + result + ". " + errorMessage);
                } else {
                    Log.i(TAG, "Result code: " + result + ". Registration successful.");
                }
            }
        });
    }

    @Override
    public void successfulScanWithResult(MRZResultModel mrzResultModel) {
        final AlertDialog alertDialog = new AlertDialog.Builder(ScannerActivity.this)
                .setMessage(mrzResultModel.toReadableString())
                .setCancelable(false)
                .setPositiveButton("Resume", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialogInterface, int i) {
                        mrzScanner.resumeScanning();
                    }
                })
                .setNegativeButton("Close", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialogInterface, int i) {
                        ScannerActivity.this.finish();
                    }
                })
                .setCancelable(false)
                .create();

        alertDialog.setOnShowListener(new DialogInterface.OnShowListener() {
            @Override
            public void onShow(DialogInterface arg0) {
                alertDialog.getButton(AlertDialog.BUTTON_NEGATIVE)
                        .setTextColor(getResources().getColor(R.color.colorPrimary));
                alertDialog.getButton(AlertDialog.BUTTON_POSITIVE)
                        .setTextColor(getResources().getColor(R.color.colorPrimary));
            }
        });

        alertDialog.show();
    }

    @Override
    public void successfulScanWithDocumentImage(Bitmap bitmap) {
        ImageView imageView = new ImageView(this);
        imageView.setImageBitmap(bitmap);

        new AlertDialog.Builder(this)
                .setMessage("Captured image")
                .setPositiveButton("Scan again", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialogInterface, int i) {
                        mrzScanner.resumeScanning();
                    }
                })
                .setNegativeButton("Close", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialogInterface, int i) {
                        ScannerActivity.this.finish();
                    }
                })
                .setView(imageView)
                .setCancelable(false)
                .show();
    }

    @Override
    public void scanImageFailed() {
    }

    @Override
    public void permissionsWereDenied() {

    }
}
